@@ -1,8 +1,8 @@
-# Test Log::Log4perl not being present.
+# Test Log::Log4perl or Log::Any::Adapter::Log4perl not being present.
 #
 package Poet::t::NoLog4perl;
 BEGIN {
-  $Poet::t::NoLog4perl::VERSION = '0.07';
+  $Poet::t::NoLog4perl::VERSION = '0.08';
 }
 use Test::Class::Most parent => 'Poet::Test::Class';
 use Module::Mask;
@@ -10,9 +10,8 @@ use Poet::Tools qw(read_file);
 use strict;
 use warnings;
 
-sub test_main : Tests {
+sub test_no_log4perl : Tests {
     my $self       = shift;
-    my $mask       = new Module::Mask('Log::Log4perl');
     my $env        = $self->initialize_temp_env();
     my $error_file = $env->logs_path("poet.log.ERROR");
     ok( -f $error_file, "$error_file exists" );
